@@ -4,6 +4,7 @@ use strict;
 use Eixo::Base::Clase;
 use URI;
 use LWP::UserAgent;
+use LWP::Protocol::https;
 use JSON -convert_blessed_universally;
 use Carp;
 use Data::Dumper;
@@ -26,22 +27,22 @@ has(
 );
 
 sub initialize{
-	my ($self, $endpoint) = @_;
+	my ($self, $endpoint, %opts) = @_;
 
 	$self->endpoint($endpoint);
 
 	die("API ENDPOINT NEEDED") unless($self->endpoint);
 
-	$self->ua($USER_AGENT_VERSION);
+	$self->ua($USER_AGENT_VERSION, %opts);
 
 	$self;
 }
 
 sub ua {
-	my ($self, $ua_str) = @_;
+	my ($self, $ua_str, %opts) = @_;
 
 	if($ua_str){
-		my $ua = LWP::UserAgent->new;
+		my $ua = LWP::UserAgent->new(%opts);
 		$ua->agent($ua_str);
 		$self->{ua} = $ua;
 	}
@@ -113,6 +114,7 @@ sub get: Log {
 
 	$uri->query_form($args{GET_DATA});
 
+
 	my $req = HTTP::Request->new(GET => $uri);
 
 	my $send_method = $args{__client_send_method};
@@ -190,6 +192,27 @@ sub put: Log {
 
     my $send_method = $args{__client_send_method};
 
+    my $headers = $args{HEADER_DATA} || {'Content-Type' => 'application/json'};
+
+    $req->header(%$headers);
+
+    my $content;
+
+    if($req->header("Content-Type") eq "application/json"){
+
+        $content = JSON->new->allow_blessed(1)
+                            ->convert_blessed(1)
+                            ->encode($args{POST_DATA} || {});
+    }
+    else{
+        
+        # raw stream
+        $content = $args{POST_DATA};
+
+    }
+
+    $req->content($content);
+
     $self->$send_method($req, %args);
 }
 
@@ -232,7 +255,7 @@ sub __send{
 
 	)->send(
 
-		$self->ua($USER_AGENT_VERSION), 
+		$self->ua(), 
 
 		$req
 
@@ -261,7 +284,7 @@ sub __sendAsync{
 
 	)->send(
 
-		$self->ua($USER_AGENT_VERSION), 
+		$self->ua(), 
 
 		$req
 
